==> gatsby-source-datocms-2.5.12.tgz: package/hooks/sourceNodes/createTypes/utils/buildFluidFields.js <==
"use strict";

var isImage = require('./isImage');

var getSizeAfterTransformations = require('./getSizeAfterTransformations');

var createUrl = require('./createUrl');

module.exports = function () {
  var field = {
    type: 'DatoCmsFluid',
    args: {
      maxWidth: {
        type: 'Int',
        defaultValue: 800
      },
      maxHeight: 'Int',
      sizes: 'String',
      imgixParams: 'DatoCmsImgixParams',
      forceBlurhash: 'Boolean'
    },
    resolve: function resolve(node, _ref) {
      var forceBlurhash = _ref.forceBlurhash,
          maxWidth = _ref.maxWidth,
          maxHeight = _ref.maxHeight,
          _ref$imgixParams = _ref.imgixParams,
          imgixParams = _ref$imgixParams === void 0 ? {} : _ref$imgixParams,
          sizes = _ref.sizes;
      var image = node.entityPayload.attributes;

      if (!isImage(image)) {
        return null;
      }

      if (node.focalPoint && imgixParams.fit === 'crop' && (imgixParams.h || imgixParams.height) && (imgixParams.w || imgixParams.width) && (!imgixParams.crop || imgixParams.crop === 'focalpoint') && !imgixParams['fp-x'] && !imgixParams['fp-y']) {
        imgixParams.crop = 'focalpoint';
        imgixParams['fp-x'] = node.focalPoint.x;
        imgixParams['fp-y'] = node.focalPoint.y;
      }

      var _getSizeAfterTransfor = getSizeAfterTransformations(image.width, image.height, imgixParams),
          finalWidth = _getSizeAfterTransfor.width,
          finalHeight = _getSizeAfterTransfor.height;

      var aspectRatio = finalWidth / finalHeight;
      var realMaxWidth = maxHeight ? maxHeight * aspectRatio : maxWidth;
      var realSizes = sizes || "(max-width: ".concat(realMaxWidth, "px) 100vw, ").concat(realMaxWidth, "px");
      var srcSet = [0.25, 0.5, 1, 1.5, 2, 3].map(function (m) {
        return realMaxWidth * m;
      }).map(Math.round).filter(function (screen) {
        return screen < finalWidth;
      }).concat([finalWidth]).map(function (screen) {
        var extraParams = {
          dpr: Math.max(0.01, Math.ceil(screen / finalWidth * 100) / 100)
        };

        if (!imgixParams.w && !imgixParams.h) {
          extraParams.w = finalWidth;
        }

        var url = createUrl(image, imgixParams, extraParams, true);
        return "".concat(url, " ").concat(Math.round(screen), "w");
      }).join(",\n");
      return {
        aspectRatio: aspectRatio,
        src: createUrl(image, imgixParams, {}, true),
        width: finalWidth,
        height: finalHeight,
        format: image.format,
        srcSet: srcSet,
        sizes: realSizes,
        forceBlurhash: forceBlurhash
      };
    }
  };
  return {
    fluid: field,
    sizes: field
  };
};

==> gatsby-source-datocms-2.5.14.tgz: package/hooks/sourceNodes/createTypes/utils/buildFluidFields.js <==
"use strict";

var isImage = require('./isImage');

var getSizeAfterTransformations = require('./getSizeAfterTransformations');

var createUrl = require('./createUrl');

var objectAssign = require('object-assign');

module.exports = function () {
  var field = {
    type: 'DatoCmsFluid',
    args: {
      maxWidth: {
        type: 'Int',
        defaultValue: 800
      },
      maxHeight: 'Int',
      sizes: 'String',
      imgixParams: 'DatoCmsImgixParams',
      forceBlurhash: 'Boolean'
    },
    resolve: function resolve(node, _ref) {
      var forceBlurhash = _ref.forceBlurhash,
          maxWidth = _ref.maxWidth,
          maxHeight = _ref.maxHeight,
          _ref$imgixParams = _ref.imgixParams,
          imgixParams = _ref$imgixParams === void 0 ? {} : _ref$imgixParams,
          sizes = _ref.sizes;
      var image = node.entityPayload.attributes;

      if (!isImage(image)) {
        return null;
      }

      var _getSizeAfterTransfor = getSizeAfterTransformations(image.width, image.height, imgixParams),
          finalWidth = _getSizeAfterTransfor.width,
          finalHeight = _getSizeAfterTransfor.height;

      var aspectRatio = finalWidth / finalHeight;
      var realMaxWidth = maxHeight ? maxHeight * aspectRatio : maxWidth;
      var realSizes = sizes || "(max-width: ".concat(realMaxWidth, "px) 100vw, ").concat(realMaxWidth, "px");
      var srcSet = [0.25, 0.5, 1, 1.5, 2, 3].map(function (m) {
        return realMaxWidth * m;
      }).map(Math.round).filter(function (screen) {
        return screen < finalWidth;
      }).concat([finalWidth]).map(function (screen) {
        var extraParams = {
          dpr: Math.max(0.01, Math.ceil(screen / finalWidth * 100) / 100)
        };

        if (!imgixParams.w && !imgixParams.h) {
          extraParams.w = finalWidth;
        }

        var url = createUrl(image.url, objectAssign({}, imgixParams, extraParams), {
          autoFormat: true,
          focalPoint: node.focalPoint
        });
        return "".concat(url, " ").concat(Math.round(screen), "w");
      }).join(",\n");
      return {
        aspectRatio: aspectRatio,
        src: createUrl(image.url, imgixParams, {
          autoFormat: true,
          focalPoint: node.focalPoint
        }),
        width: finalWidth,
        height: finalHeight,
        format: image.format,
        srcSet: srcSet,
        sizes: realSizes,
        forceBlurhash: forceBlurhash
      };
    }
  };
  return {
    fluid: field,
    sizes: field
  };
};
